@@ -4,33 +4,29 @@
 #' John Zobitz \email{zobitz@augsburg.edu}
 
 #' @description
-#' Given an environmental measurement data frame, show when the environmental measurements produced a QF value
-#' @param input_fluxes data frame of environmental measurements
+#' Given a flux measurement data frame, show when the environmental measurements produced a QF value
+#' @param input_fluxes data frame of computed fluxes
 #'
 #' @return A ggplot graph where we have ordered factors showing the QA values a given environmental measurement
 #' @export
 #'
 #' @examples
 #' # Make a fingerprint plot for environmental variables:
-#' env_fingerprint_plot(sjer_flux_2022_06$millington_quirk)
-#' # Can also use
-#' env_fingerprint_plot(sjer_flux_2022_06$marshall)
-#' # (although the input env data are the same for both diffusivity calculations)
-
+#' env_fingerprint_plot(sjer_flux_2022_06)
 
 # changelog and author contributions / copyrights
 #   John Zobitz (2024-04-07)
 #     original creation
 #     2024-04-08: update to get namespaces correct
 #     2024-05-07: colorscheme updates
-#     2025-08-23: updated documentation
+#     2025-11-17: update to name of surface diffusivity column
 
 env_fingerprint_plot <- function(input_fluxes) {
 
   .data = NULL  # Appease R CMD Check
 
   prep_env <- input_fluxes |>
-    dplyr::select(-.data[["flux_compute"]], -.data[["diffusivity"]]) |>
+    dplyr::select(-.data[["flux_compute"]], -.data[["surface_diffusivity"]]) |>
     dplyr::mutate(
       week_day = lubridate::wday(.data[["startDateTime"]]),
       decimal_hour = lubridate::hour(.data[["startDateTime"]]) + lubridate::minute(.data[["startDateTime"]]) / 60,
